Index: h323/ast_h323.cpp
===================================================================
--- h323/ast_h323.cpp	(revision 8990)
+++ h323/ast_h323.cpp	(working copy)
@@ -583,6 +583,7 @@
 	if (h323debug) {
 		cout << "	== New H.323 Connection created." << endl;
 	}
+	redirPort = 0;
 	return;
 }
 
@@ -1058,10 +1059,16 @@
 		cout << "\tERROR: on_external_rtp_create failure" << endl;
 		return;
 	} else {
+		connection.sessionId = id;
 		localIpAddr = info->addr;
 		localPort = info->port;
 		/* tell the H.323 stack  */ 
-		SetExternalAddress(H323TransportAddress(localIpAddr, localPort), H323TransportAddress(localIpAddr, localPort + 1));
+		if(connection.redirPort) {
+		    cout << "Redirecting media to [" << connection.redirIpAddr << "] port [" << connection.redirPort << "]" << endl;
+		    SetExternalAddress(H323TransportAddress(connection.redirIpAddr, connection.redirPort), H323TransportAddress(localIpAddr, localPort + 1));
+		} else {
+		    SetExternalAddress(H323TransportAddress(localIpAddr, localPort), H323TransportAddress(localIpAddr, localPort + 1));
+		}
 		/* clean up allocated memory */
 		free(info);
 	}
@@ -1127,6 +1134,7 @@
 	return FALSE;
 }
 
+
 /** IMPLEMENTATION OF C FUNCTIONS */
 
 /**
@@ -1486,24 +1494,36 @@
 }
 
 /* alas, this doesn't work :(   */
-void h323_native_bridge(const char *token, const char *them, char *capability)
+int h323_native_bridge(const char *token, sockaddr_in them, char *capability)
 {
 	H323Channel *channel;
-	MyH323Connection *connection = (MyH323Connection *)endPoint->FindConnectionWithLock(token);
+	MyH323Connection * connection;
+	char iabuf[INET_ADDRSTRLEN];
 	
+	connection  = (MyH323Connection *)endPoint->FindConnectionWithLock(token);
+	
 	if (!connection) {
-		cout << "ERROR: No connection found, this is bad\n";
-		return;
+		cout << "ERROR: No connection found, this is bad" << endl;
+		return 1;
 	}
 
-	cout << "Native Bridge:  them [" << them << "]" << endl; 
+//	cout << "Native Bridge:  them [" << them << "] (" << token << ")" << endl; 
 
 	channel = connection->FindChannel(connection->sessionId, TRUE);
+	if (!channel) {
+		cout << "ERROR: No channel found for [" << connection->sessionId << "], this is bad" << endl;
+		return 1;
+	}
 	connection->bridging = TRUE;
-	connection->CloseLogicalChannelNumber(channel->GetNumber());
+	ast_inet_ntoa(iabuf, sizeof(iabuf), them.sin_addr);
+	connection->redirIpAddr = PIPSocket::Address(PString(iabuf));
+	connection->redirPort = ntohs(them.sin_port);
+	cout << "Closing all logical channels (fromRemote=TRUE)" << endl;
 	
+	connection->CloseAllLogicalChannels(TRUE);
+	
 	connection->Unlock();
-	return;
+	return 0;
 
 }
 
Index: h323/ast_h323.h
===================================================================
--- h323/ast_h323.h	(revision 8990)
+++ h323/ast_h323.h	(working copy)
@@ -187,6 +187,9 @@
 	WORD sessionId;
 	BOOL bridging;			
 
+	PIPSocket::Address redirIpAddr;
+        WORD redirPort;
+
 	unsigned progressSetup;
 	unsigned progressAlert;
 	int cause;
@@ -195,6 +198,7 @@
 
 	PString ast_cid_num;
 	PString ast_cid_name;
+
 };
 
 class MyH323_ExternalRTPChannel : public H323_ExternalRTPChannel {
Index: h323/chan_h323.h
===================================================================
--- h323/chan_h323.h	(revision 8990)
+++ h323/chan_h323.h	(working copy)
@@ -211,7 +211,7 @@
 	/* H323 listener related funcions */
 	int h323_start_listener(int, struct sockaddr_in);
 
-	void h323_native_bridge(const char *, const char *, char *);
+	int h323_native_bridge(const char *, struct sockaddr_in, char *);
 
 	/* Send a DTMF tone to remote endpoint */
 	void h323_send_tone(const char *call_token, char tone);
